@@ -1,9 +1,9 @@
 #  OUTPUT
 
-write.fit <- function(fit, results=NULL, file, digits=2, adjust="none", sep="\t", ...) {
+write.fit <- function(fit, results=NULL, file, digits=3, adjust="none", sep="\t", ...) {
 #	Write an MArrayLM fit to a file
 #	Gordon Smyth
-#	14 Nov 2003.  Last modified 30 August 2006.
+#	14 Nov 2003.  Last modified 24 February 2007.
 
 	if(!is(fit, "MArrayLM")) stop("fit should be an MArrayLM object")
 	if(!is.null(results) && !is(results,"TestResults")) stop("results should be a TestResults object")
@@ -12,7 +12,12 @@ write.fit <- function(fit, results=NULL, file, digits=2, adjust="none", sep="\t"
 	p.value <- as.matrix(fit$p.value)
 	for (j in 1:ncol(p.value)) p.value[,j] <- p.adjust(p.value[,j],method=adjust)
 
-	rn <- function(x,digits=digits) if(is.null(x)) NULL else round(x,digits=digits)
+	rn <- function(x,digits=digits) if(is.null(x))
+		NULL
+	else {
+		if(is.matrix(x) && ncol(x)==1) x <- x[,1]
+		round(x,digits=digits)
+	}
 	tab <- list()
 	tab$A <- rn(fit$Amean,digits=digits-1)
 	tab$Coef <- rn(fit$coef,digits=digits)
